# Jabutiles

A procedural Tileset interface for games.

Provides support for orthogonal, isometric and hexagonal tiles.

Most of the backend is pillow (a PIL fork), the rest is numpy.

[Documentation](docs/technical.md)
